==================
Contribution guide
==================

This is contribution guide for aqtinstall project.
You are welcome to send a Pull-Request, reporting bugs and ask questions.

Resources
=========

- Project owner: Hiroshi Miura
- Bug Tracker:  Github issue `Tracker`_
- Status: alpha
- Activity: high

.. _`Tracker`: https://github.com/miurahr/aqtinstall/issues

Bug triage
==========

Every report to github issue tracker should be in triage.
whether it is bug, question or invalid.


Send patch
==========

Here is small amount rule when you want to send patch the project;

1. every proposal for modification should send as 'Pull Request'

1. each pull request can consist of multiple commits.

1. you are encourage to split modifications to individual commits that are logical subpart.

CI tests
=========

The project configured to use Azure Pipelines, Travis-CI and CoverAlls for regression test.
You can see test results on badge and see details in a web page linked from badge.
